=======================
Configuration Reference
=======================

This section provides detailed information on many of Kayobe's configuration
options.

.. toctree::
   :maxdepth: 2

   kayobe
   ansible
   os-distribution
   physical-network
   network
   routed-control-plane-networks
   hosts
   kolla
   kolla-ansible
   bifrost
   overcloud-dib
   ironic-python-agent
   docker-registry
   seed-custom-containers
   infra-vms
   nova-cells
